@@ -8,6 +8,9 @@ import time, traceback, collections, logging
 from twisted.internet import reactor
 from twisted.protocols.basic import LineReceiver
 
+# Say that we can take up to 10 mb at a time
+LineReceiver.MAX_LENGTH = 1024 * 1024 * 10 
+
 from pybc.Block import Block
 from pybc.util import string2bytes, bytes2string
 
@@ -446,6 +449,17 @@ class BlockchainProtocol(LineReceiver):
         # runs.
         reactor.callInThread(self.handle_message, parts)
         
+    def lineLengthExceeded(self, line):
+        """
+        The peer sent us a line that is too long.
+        
+        Complain about it so the user knows that's why we're dropping
+        connections.
+        
+        """
+        
+        logging.error("Peer sent excessively long line.")
+        
     def process_inv_queue(self):
         """
         Download some blocks from the queue of blocks we know we need.
