@@ -964,6 +964,11 @@ class CoinBlockchain(TransactionalBlockchain):
             # This is a fee-collecting/reward-collecting transaction. We can't
             # verify them individually, but we can make sure the total they come
             # to is not too big or too small in verify_payload.
+            
+            if advance and state is not None:
+                # We're supposed to advance the state since transaction is valid
+                state.apply_transaction(transaction)
+            
             return True
         
         # Now we know the transaction has inputs. Check them.
@@ -1018,8 +1023,11 @@ class CoinBlockchain(TransactionalBlockchain):
         # the block. It can still be rendered invalid after that, though.
         with self.lock:
         
+            logging.debug("Making a block")
+        
             if not self.state_available:
                 # We can't mine without the latest State
+                logging.debug("Can't make block without State")
                 return None
         
             # This holds the list of Transaction objects to include
@@ -1091,6 +1099,8 @@ class CoinBlockchain(TransactionalBlockchain):
                 transactions.pack_transactions(
                 [transaction.to_bytes() for transaction in to_include]))
                 
+            if block is None:
+                logging.debug("Base class cound not make block")
             return block
             
             # next_state gets discarded without being committed, which is
